Crate scadman_helper

Crate scadman_helper 

Helper library for creating 3D drawings using scadman.

This crate provides tools and structures to define 3D geometry and shapes, and convert them into OpenSCAD syntax using the scadman crate.

Modules

geometry
Provides geometric primitives and utilities.
shapes
Provides definitions for various 3D shapes.
transform
Transformation utilities.

Functions

to_openscad_rotate_angles
Converts a 3D rotation matrix into Euler angles (XYZ) in radians.